import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Manage the organization secret
 *
 * @schema CfnSecretProps
 */
export interface CfnSecretProps {
    /**
     * @schema CfnSecretProps#Org
     */
    readonly org: string;
    /**
     * @schema CfnSecretProps#SecretValue
     */
    readonly secretValue?: string;
    /**
     * @schema CfnSecretProps#SecretName
     */
    readonly secretName: string;
    /**
     * @schema CfnSecretProps#Name
     */
    readonly name?: string;
    /**
     * @schema CfnSecretProps#SelectedRepositoryIds
     */
    readonly selectedRepositoryIds?: number[];
    /**
     * @schema CfnSecretProps#Visibility
     */
    readonly visibility: Visibility;
    /**
     * @schema CfnSecretProps#CreatedAt
     */
    readonly createdAt?: Date;
    /**
     * @schema CfnSecretProps#UpdatedAt
     */
    readonly updatedAt?: Date;
}
/**
 * Converts an object of type 'CfnSecretProps' to JSON representation.
 */
export declare function toJson_CfnSecretProps(obj: CfnSecretProps | undefined): Record<string, any> | undefined;
/**
 * Which type of organization repositories have access to the organization secret. selected means only the repositories specified by selected_repository_ids can access the secret.
 *
 * @schema Visibility
 */
export declare enum Visibility {
    /** all */
    ALL = "all",
    /** private */
    PRIVATE = "private",
    /** selected */
    SELECTED = "selected"
}
/**
 * A CloudFormation `GitHub::Organizations::Secret`
 *
 * @cloudformationResource GitHub::Organizations::Secret
 * @stability external
 * @link https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git
 */
export declare class CfnSecret extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "GitHub::Organizations::Secret";
    /**
     * Resource props.
     */
    readonly props: CfnSecretProps;
    /**
     * Attribute `GitHub::Organizations::Secret.SelectedRepositoriesUrl`
     * @link https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git
     */
    readonly attrSelectedRepositoriesUrl: string;
    /**
     * Create a new `GitHub::Organizations::Secret`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnSecretProps);
}
